2022-04-14 Version: 1.0.10
- Fix auth bug.

2022-04-13 Version: 1.0.9
- Support HTTP Trigger invocation.

2022-04-01 Version: 1.0.8
- Change qualifier to query.

2022-04-01 Version: 1.0.7
- Update fc pop sdk.

2022-04-01 Version: 1.0.6
- Update fc pop sdk.

2021-12-10 Version: 1.0.5
- Update fc pop sdk.

2021-12-03 Version: 1.0.4
- Update fc pop sdk.

2021-12-03 Version: 1.0.3
- Update fc pop sdk.

2021-12-02 Version: 1.0.2
- Add CustomDNS, CustomRuntimeConfig field for createFunction, updateFunction and getFunction.

2021-10-26 Version: 1.0.0
- Update fc pop sdk.

